@@ -8,8 +8,8 @@ use url::Url;
 
 // For smaller sample sizes, you may have to increase this to have the transactions mined.
 const REWARD_MULTIPLIER: f32 = 2.0;
-const NUM_FILES: usize = 20;
-const FILE_SIZE: usize = 5_000_000;
+const NUM_FILES: usize = 1_000;
+const FILE_SIZE: usize = 100_000;
 const BUNDLE_SIZE: u64 = 100_000_000;
 const BUFFER: usize = 5;
 
